class CollectionBuilder < Builder
  ##
  # Receive a list of ids and return a list of collections
  # Each element, must be a Hash with rid and last_modified
  #
  # Example:
  #   collection = CollectionBuilder.build [{'rid' => '#14:15', 'last_modified' => '2015-02-10 15:30'}]
  #
  # If the last_modified param is null, the object will be always reconstructed and updated in the cache
  def self.build(collections = [])
    super(subject_repository, collections, true, 'rid')
  end

  def self.build_from_orientdb(args = {})
    super(args) do
      type = (args['name'] == 'Bookmarks') ? Bookmarks : Collection
      obj = type.new(
        learning_objects: LearningObjectBuilder.build(map_rid_to_object(args['learning_objects']) || []),
        privacy: args['privacy'],
        id: args['@rid']
      )
      obj.name = args['name'] unless type == Bookmarks
      obj.owner = collection_repository.owner(args['@rid'])
      obj.created_at = DateTime.strptime(args['created_at'], "%Y-%m-%d %H:%M:%S") unless args['created_at'].nil?
      obj.last_modified = DateTime.strptime(args['last_modified'], "%Y-%m-%d %H:%M:%S") unless args['last_modified'].nil?
      obj
    end
  end

  def self.map_rid_to_object(ids)
    return {'rid' => ids} if ids.class == String

    ids.map do |id|
      {'rid' => id}
    end
  end
end
